@@ -26,8 +26,7 @@ from collections import namedtuple
 
 import requests
 from dateutil.parser import parse as dateutil_parser
-from requests.exceptions import Timeout
-from urllib3.exceptions import TimeoutError
+from requests.exceptions import ConnectionError, ConnectTimeout
 
 PY2 = sys.version_info[0] < 3
 
@@ -121,6 +120,7 @@ def parse_datetime(s, **kwargs):
     try:
         ret = dateutil_parser(s, **kwargs)
     except (OverflowError, TypeError, ValueError) as e:
+        logger.exception(e, exc_info=True)
         reraise('datetime parsing error from %s' % s, e)
     return ret
 
@@ -137,6 +137,9 @@ class BaseAPI(object):
     def __init__(self, api_key, host='localhost', port=8384,
                  timeout=DEFAULT_TIMEOUT, is_https=False, ssl_cert_file=None):
 
+        if is_https and not ssl_cert_file:
+            logger.warning('using https without specifying ssl_cert_file')
+
         if ssl_cert_file:
             if not os.path.exists(ssl_cert_file):
                 raise SyncthingError(
@@ -149,7 +152,7 @@ class BaseAPI(object):
         self.port = port
         self.ssl_cert_file = ssl_cert_file
         self.timeout = timeout
-        self.verify = True if ssl_cert_file or is_https else False
+        self.verify = True if ssl_cert_file else False
         self._headers = {
             'X-API-Key': api_key
         }
@@ -196,6 +199,7 @@ class BaseAPI(object):
                 data=json.dumps(data),
                 params=params,
                 timeout=self.timeout,
+                verify=self.verify,
                 cert=self.ssl_cert_file,
                 headers=headers
             )
@@ -206,6 +210,7 @@ class BaseAPI(object):
         except requests.RequestException as e:
             if raw_exceptions:
                 raise e
+            logger.exception(e)
             reraise('http request error', e)
 
         else:
@@ -794,15 +799,6 @@ class Events(BaseAPI):
         """
         return self._count
 
-    @property
-    def last_seen_id(self):
-        """ The id of the last seen event.
-
-            Returns:
-                int
-        """
-        return self._last_seen_id
-
     def disk_events(self):
         """ Blocking generator of disk related events. Each event is
         represented as a ``dict`` with metadata.
@@ -864,19 +860,19 @@ class Events(BaseAPI):
 
             try:
                 data = self.get(using_url, params=params, raw_exceptions=True)
-            except (Timeout, TimeoutError) as e:
+            except (ConnectTimeout, ConnectionError) as e:
                 # swallow timeout errors for long polling
                 data = None
             except Exception as e:
                 reraise('', e)
 
             if data:
+                # update our last_seen_id to move our event counter forward
+                self._last_seen_id = data[-1]['id']
                 for event in data:
                     # handle potentially multiple events returned in a list
                     self._count += 1
                     yield event
-                # update our last_seen_id to move our event counter forward
-                self._last_seen_id = data[-1]['id']
 
     def __iter__(self):
         """ Helper interface for :obj:`._events` """
